==> groupfolders-v20.1.2.tar.gz: groupfolders/l10n/uk.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Ви не можете вилучити в себе самого дозвіл на читання.",
    "Team folders" : "Каталоги команд",
    "Team Folders" : "Каталоги для команд",
    "Shared folders managed by admins, accessible to designated teams with configurable permissions and quotas" : "Спільні каталоги, якими керують адміністратори, доступні визначеним командам із можливістю налаштувати права доступу та квоти",
    "Unset" : "Зняти",
    "Denied (Inherited permission)" : "Відмовлено (успадкований дозвіл)",
    "Allowed (Inherited permission)" : "Дозволено (успадкований дозвіл) ",
    "Denied" : "Заборонено",
    "Allowed" : "Дозволено",
    "Access denied" : "Доступ заборонено",
    "Access allowed" : "Доступ дозволено",
    "Inherit permission" : "Успадкований дозвіл",
    "Deny" : "Заборонити",
    "Allow" : "Дозволити",
    "Group" : "Група",
    "Team" : "Команда",
    "Team folder" : "Каталог команди",
    "Read" : "Читати",
    "Write" : "Змінювати",
    "Create" : "Додати",
    "Delete" : "Вилучати",
    "Share" : "Спільний доступ",
    "You" : "Ви",
    "Remove access rule" : "Вилучити правило доступу",
    "Add advanced permission rule" : "Додати складне правило доступу",
    "Select a user or group" : "Виберіть користувача або групу",
    "Open Team folder" : "Відкрити каталог команди",
    "Permission denied. User does not have sufficient permissions." : "Доступ заборонено. Користувач не має достатніх прав.",
    "Unexpected status from server" : "Неочікуваний стан сервера",
    "List of Team folders." : "Список каталогів команди.",
    "No Team folders yet" : "Поки відсутні каталоги команди",
    "Team folders will show up here" : "Каталоги команди буде показано тут",
    "Add group" : "Додати групу",
    "Default" : "Типово",
    "Unlimited" : "Необмежено",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Справді вилучити каталог \"{folderName}\" та всі файли в ньому? Цю операцію неможливо буде скасувати",
    "Delete \"{folderName}\"?" : "Вилучити \"{folderName}\"?",
    "Team folder admin delegation" : "Делегування адміністративних прав на каталог команди",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud дозволяє делегувати адміністрування каталогами команд користувачам без адміністративного рівня доступу.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Зазначте нижче групи, які матимуть право керувати каталогами команд та використовувати їхні API/REST.",
    "They will have access to all Team folders." : "Вони матимуть доступ до всіх каталогів команди.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Зазначте нижче групи, які матимуть право керувати каталогами команд та використовувати лише їхній API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Вони матимуть доступ тільки до каталогів команди згідно з додатковими дозволами.",
    "Group or team" : "Група або команда",
    "Sort by number of groups or teams that have access to this folder" : "Впорядковувати за кількістю груп або команд, які мають доступ до цього каталогу",
    "Sort by number of groups that have access to this folder" : "Впорядковувати за кількістю груп, які мають доступ до цього каталогу",
    "Folder name" : "Назва каталогу",
    "Quota" : "Обмеження",
    "Advanced Permissions" : "Розширені права доступу",
    "Pagination of team folders" : "Відступ для каталогів команд",
    "Previous" : "Назад",
    "Next" : "Далі",
    "User" : "Користувач",
    "Unknown" : "Невідомо",
    "Users/groups that can manage" : "Користувачі/групи, які мають право керування",
    "None" : "Нічого",
    "No other groups or teams available" : "Більше немає доступних груп або команд",
    "No other groups available" : "Більше немає доступних груп",
    "{displayName} (team)" : "{displayName} (команда)",
    "Add group or team" : "Додати групу або команду",
    "{size} used" : "{size} використано",
    "Other …" : "Інше ...",
    "Admin configured folders shared with everyone in a team" : "Адміністратор сконфігурував каталоги, до яких було надано доступ для всіх у команді",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Адміністратор налаштував спільні каталоги зі всіма у команді.\n\nКаталоги можна налаштувати у розділі адміністративних налаштувань \"Каталоги команди\".\n\nПісля створення каталогу адміністратор може надавати доступ до каталогу одній або кільком командам, контролювати їхні повноваження на запис та надання доступу, визначати квоту каталогу.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Адміністратор налаштував каталоги, якими поділився зі всіма учасниками команди.\n\nКаталоги можна налаштувати у розділі *Каталоги команд* у налаштуваннях адміністрування.\n\nПісля створення каталогу адміністратор може надати доступ до каталогу одній чи більше командам, встановити дозволи на запис/поширення, визначити квоту сховища каталогу.\nВід версіх Hub 10/Nextcloud 31 адміністратор має бути частиною команди, щоби мати право призначиати команду до відповідного каталогу команди."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> groupfolders-v20.1.7.tar.gz: groupfolders/l10n/uk.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Ви не можете вилучити в себе самого дозвіл на читання.",
    "Team folders" : "Каталоги команд",
    "Team Folders" : "Каталоги для команд",
    "Shared folders managed by admins, accessible to designated teams with configurable permissions and quotas" : "Спільні каталоги, якими керують адміністратори, доступні визначеним командам із можливістю налаштувати права доступу та квоти",
    "Denied (Inherited permission)" : "Відмовлено (успадкований дозвіл)",
    "Allowed (Inherited permission)" : "Дозволено (успадкований дозвіл) ",
    "Denied" : "Заборонено",
    "Allowed" : "Дозволено",
    "Access denied" : "Доступ заборонено",
    "Access allowed" : "Доступ дозволено",
    "Inherit permission" : "Успадкований дозвіл",
    "Deny" : "Заборонити",
    "Allow" : "Дозволити",
    "Group" : "Група",
    "Team" : "Команда",
    "Advanced permissions for Team folder" : "Розширені права доступу для каталогів команди",
    "Team folder" : "Каталог команди",
    "Read" : "Читати",
    "Write" : "Змінювати",
    "Create" : "Додати",
    "Delete" : "Вилучати",
    "Share" : "Спільний доступ",
    "You" : "Ви",
    "Remove access rule" : "Вилучити правило доступу",
    "Add new rule" : "Додати нове правило",
    "Select a user or group" : "Виберіть користувача або групу",
    "Open Team folder" : "Відкрити каталог команди",
    "Permission denied. User does not have sufficient permissions." : "Доступ заборонено. Користувач не має достатніх прав.",
    "Unexpected status from server" : "Неочікуваний стан сервера",
    "List of Team folders." : "Список каталогів команди.",
    "No Team folders yet" : "Відсутні каталоги команд",
    "Team folders will show up here" : "Каталоги команди буде показано тут",
    "Add group" : "Додати групу",
    "Default" : "Типово",
    "Unlimited" : "Необмежено",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Справді вилучити каталог \"{folderName}\" та всі файли в ньому? Цю операцію неможливо буде скасувати",
    "Delete \"{folderName}\"?" : "Вилучити \"{folderName}\"?",
    "Team folder admin delegation" : "Делегування адміністративних прав на каталог команди",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud дозволяє делегувати адміністрування каталогами команд користувачам без адміністративного рівня доступу.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Зазначте нижче групи, які матимуть право керувати каталогами команд та використовувати їхні API/REST.",
    "They will have access to all Team folders." : "Вони матимуть доступ до всіх каталогів команди.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Зазначте нижче групи, які матимуть право керувати каталогами команд та використовувати лише їхній API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Вони матимуть доступ тільки до каталогів команди згідно з додатковими дозволами.",
    "Group or team" : "Група або команда",
    "Sort by number of groups or teams that have access to this folder" : "Впорядковувати за кількістю груп або команд, які мають доступ до цього каталогу",
    "Sort by number of groups that have access to this folder" : "Впорядковувати за кількістю груп, які мають доступ до цього каталогу",
    "Advanced permissions allows setting permissions on a per-file basis but comes with a performance overhead" : "Розширені права доступу дозволяють встановлювати доступ для кожного окремого файлу, проте це впливатиме на продуктивність системи.",
    "Folder name" : "Назва каталогу",
    "Quota" : "Обмеження",
    "Advanced Permissions" : "Розширені права доступу",
    "Do not grant any advanced permissions by default" : "Типово не надавати жодних розширених прав доступу",
    "Pagination of team folders" : "Відступ для каталогів команд",
    "Previous" : "Назад",
    "Next" : "Далі",
    "User" : "Користувач",
    "Unknown" : "Невідомо",
    "Users/groups that can manage" : "Користувачі/групи, які мають право керування",
    "None" : "Нічого",
    "No other groups or teams available" : "Більше немає доступних груп або команд",
    "No other groups available" : "Більше немає доступних груп",
    "{displayName} (team)" : "{displayName} (команда)",
    "Add group or team" : "Додати групу або команду",
    "{size} used" : "{size} використано",
    "Other …" : "Інше ...",
    "Admin configured folders shared with everyone in a team" : "Адміністратор сконфігурував каталоги, до яких було надано доступ для всіх у команді",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Адміністратор налаштував спільні каталоги зі всіма у команді.\n\nКаталоги можна налаштувати у розділі адміністративних налаштувань \"Каталоги команди\".\n\nПісля створення каталогу адміністратор може надавати доступ до каталогу одній або кільком командам, контролювати їхні повноваження на запис та надання доступу, визначати квоту каталогу.",
    "Unset" : "Зняти",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Адміністратор налаштував каталоги, якими поділився зі всіма учасниками команди.\n\nКаталоги можна налаштувати у розділі *Каталоги команд* у налаштуваннях адміністрування.\n\nПісля створення каталогу адміністратор може надати доступ до каталогу одній чи більше командам, встановити дозволи на запис/поширення, визначити квоту сховища каталогу.\nВід версіх Hub 10/Nextcloud 31 адміністратор має бути частиною команди, щоби мати право призначиати команду до відповідного каталогу команди."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
